==> xmame-0_36b1_2.tgz: xmame-0.36b1.2/src/unix/xmame.h <==
/*
 ******************* X-Mame header file *********************
 * file "xmame.h"
 *
 * by jantonio@dit.upm.es
 *
 ************************************************************
*/

#ifndef __XMAME_H_
#define __XMAME_H_

#ifdef __MAIN_C_
#define EXTERN
#else
#define EXTERN extern
#endif

/*
 * Include files.
 */

#ifdef openstep
#include <libc.h>
#include <math.h>
#endif /* openstep */

#if defined svgalib || defined svgafx
#include <vga.h>
#endif

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <ctype.h>
#include <pwd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "osdepend.h"
#include "mame.h"

#ifdef MAME_NET
/* Network */
 
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>

#endif /* MAME_NET */

/*
 * Definitions.
 */

#ifndef TRUE
#define	TRUE			(1)
#endif

#ifndef FALSE
#define FALSE			(0)
#endif

#define OSD_OK			(0)
#define OSD_NOT_OK		(1)

#define DEBUG(x)

#define MAXPATHC 20 /* at most 20 path entries */
#define MAXPATHL 512 /* at most 511 character path length */

#ifdef  HAVE_GETTIMEOFDAY

typedef long uclock_t;
uclock_t uclock(void);
#define UCLOCKS_PER_SEC 1000000

#else

typedef clock_t uclock_t
#if (CLOCKS_PER_SEC < 1000)
/* the resolution of the normal clock() call isn't good enough, unless the
   framerate is a division of 100, so we fake a higher resolution */
#define uclock() (clock() << 5)
#define UCLOCKS_PER_SEC (CLOCKS_PER_SEC << 5)
#else
#define UCLOCKS_PER_SEC CLOCKS_PER_SEC
#define uclock() clock()
#endif

#endif

enum { LIST_LIST = 1, LIST_FULL, LIST_GAMES, LIST_CLONES,
   LIST_DETAILS, LIST_ROMS, LIST_SAMPLES, LIST_SAMDIR, LIST_CRC, LIST_DUPCRC, LIST_INFO,
   LIST_COLORS, LIST_LMR, LIST_WRONGORIENTATION, VERIFY_ROMS, VERIFY_SAMPLES };

enum { X11_WINDOW, X11_DGA };

enum { JOY_NONE, JOY_I386, JOY_PAD, JOY_X11, JOY_I386NEW };

/* Taken from common.h since the rest of common.h creates to many conflicts
   with X headers */
struct my_rectangle
{
	int min_x,max_x;
	int min_y,max_y;
};

/*
 * Global variables.
 */

#ifdef MAME_NET
/* Network Variables */
EXTERN int netstate;
EXTERN char global_key[128]; /* keystate table of all pc's in a net game. */
#endif

/* dirty stuff */
#if defined svgalib || defined x11 || defined xfx || defined svgafx || defined ggi
EXTERN unsigned char *dirty_lines;
EXTERN unsigned char **dirty_blocks;
EXTERN unsigned char *old_dirty_lines;
EXTERN unsigned char **old_dirty_blocks;
#endif

/* global variables and miscellaneous flags */

EXTERN int              root_window_id; /* root window id (for swallowing the mame window) */
EXTERN int	 	widthscale;     /* X scale */
EXTERN int	 	heightscale;    /* Y SCALE */
EXTERN float	 	widthscale_f;
EXTERN float	 	heightscale_f;
EXTERN char		*vector_res;
EXTERN char		*geometry;
EXTERN char		rompath[MAXPATHL];
EXTERN char		*spooldir;      /* directory to store high scores */
EXTERN char		*screenshot_dir;
EXTERN char		*home_dir;
EXTERN char		*towns_pad_dev; /* name of FM-TOWNS device */
EXTERN char 		*x11joyname;
EXTERN char             *audiodevice;   /* /dev/dsp or /dev/audio */
EXTERN char		*key;           /* keystate table used by the core  */
EXTERN char		*local_key;     /* keystate table of local keyboard */
EXTERN char		title[50]; 
EXTERN int		swapjoyaxis;
EXTERN int		analogstick;
EXTERN int		analogmouse;
EXTERN int		joytype;
EXTERN int		use_mouse;
EXTERN int		use_dirty;
EXTERN int		use_profiler;
EXTERN int		play_sound;
EXTERN int		fake_sound;
EXTERN int		sound_8bit;   /* Sample down to 8bit sound? */
EXTERN int		sound_stereo; /* Do stereo sound? */
EXTERN int		use_private_cmap;
EXTERN int		use_xsync;
EXTERN int		use_tweak;
EXTERN int		use_planar;
EXTERN int		use_linear;
EXTERN int		throttle;
EXTERN int		autoframeskip;
EXTERN int		frameskip;
EXTERN int		snapshot_no;
EXTERN int		game_index;
EXTERN struct osd_bitmap *bitmap;
EXTERN int		frag_size;
EXTERN int		num_frags;
EXTERN int 		use_mit_shm;  /* use mitshm if available */
EXTERN float		gamma_correction;
EXTERN int		brightness;
EXTERN int		totalcolors;
EXTERN int		attenuation;
EXTERN int		x11_video_mode;
EXTERN int		x11_grab_mouse;
EXTERN int		use_xil;
EXTERN int		use_mt_xil;
EXTERN int		show_cursor;
EXTERN int		use_scanlines;
EXTERN int		netkeymap;
EXTERN int		players;
EXTERN char		*mastername;
EXTERN int		doublebuffer;
EXTERN int		cabview;
EXTERN char		*cabname;
EXTERN float		fxgamma;
EXTERN int		use_winkeys;

/* visual is the visual part of the bitmap */
EXTERN int 		visual_width;
EXTERN int		visual_height;
EXTERN struct my_rectangle visual;

/* File descripters for stdout / stderr redirection, without svgalib inter
   fering */
EXTERN FILE *stdout_file;
EXTERN FILE *stderr_file;

/* system dependent functions */
int  sysdep_init(void);
int  sysdep_create_display(void);
void sysdep_alloc_palette(void);
void sysdep_modify_pen(int pen, unsigned char red,unsigned char green,unsigned char blue);
void sysdep_mark_palette_dirty(void);
void sysdep_update_display(void);
int  sysdep_set_video_mode(void);
void sysdep_set_text_mode(void);
void sysdep_disable_mode(char *mode_string);

/* audio related */
int  start_timer();
int  osd_audio_init(void);
void osd_audio_close(void);
void osd_audio_update(void);
int  sysdep_audio_init(void);
void sysdep_audio_close(void);
long sysdep_audio_get_freespace(void);
int  sysdep_audio_play(unsigned char *buf, int size);

/* input related */
int  osd_input_initpre(void);
int  osd_input_initpost(void);
void osd_input_close(void);
void sysdep_update_keyboard (void);
int  sysdep_mapkey(int from, int to);
int  key_to_pseudo_code(int k);
void sysdep_mouse_poll(void);

/* dirty functions */
int  osd_dirty_init(void);
void osd_dirty_close(void);
void osd_dirty_merge(void);

/* profiler functions */
void osd_profiler_init(void);
void osd_profiler_display(void);

/* network funtions */
int  osd_net_init(void);
void osd_net_close(void);

/* debug functions */
int  osd_debug_init(void);
void osd_debug_close(void);

/* miscelaneous */
int get_config (int argc, char *argv[]);
int frontend_list(int list, char *gamename, int showclones);
int frontend_list_clones(char *gamename);
void init_rom_path(void);
void romident(const char* name, int enter_dirs);

#undef EXTERN
#endif

==> xmame-0.36.1.tgz: xmame-0.36.1/src/unix/xmame.h <==
/*
 ******************* X-Mame header file *********************
 * file "xmame.h"
 *
 * by jantonio@dit.upm.es
 *
 ************************************************************
*/

#ifndef __XMAME_H_
#define __XMAME_H_

#ifdef __MAIN_C_
#define EXTERN
#else
#define EXTERN extern
#endif

/*
 * Include files.
 */

#ifdef openstep
#include <libc.h>
#include <math.h>
#endif /* openstep */

#if defined svgalib || defined svgafx
#include <vga.h>
#endif

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <ctype.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "osdepend.h"
#include "mame.h"
#include "sysdep/sysdep_palette.h"
#include "sysdep/rc.h"

/*
 * Definitions.
 */

#ifndef TRUE
#define	TRUE			(1)
#endif

#ifndef FALSE
#define FALSE			(0)
#endif

#define OSD_OK			(0)
#define OSD_NOT_OK		(1)

#define DEBUG(x)

#define FRAMESKIP_LEVELS 12

/* Taken from common.h since the rest of common.h creates to many conflicts
   with X headers */
struct my_rectangle
{
	int min_x,max_x;
	int min_y,max_y;
};

/*
 * Global variables.
 */

#ifdef MAME_NET
/* Network Variables */
EXTERN int netstate;
EXTERN char global_key[128]; /* keystate table of all pc's in a net game. */
#endif

/* dirty stuff */
#if !defined xgl
EXTERN unsigned char *dirty_lines;
EXTERN unsigned char **dirty_blocks;
EXTERN unsigned char *old_dirty_lines;
EXTERN unsigned char **old_dirty_blocks;
#endif

/* global variables and miscellaneous flags */

EXTERN int	 	widthscale;     /* X scale */
EXTERN int	 	heightscale;    /* Y SCALE */
EXTERN char		*home_dir;
EXTERN char		*key;           /* keystate table used by the core  */
EXTERN char		*local_key;     /* keystate table of local keyboard */
EXTERN char		title[50]; 
EXTERN int		use_mouse;
EXTERN int		use_dirty;
EXTERN int		throttle;
EXTERN int		autoframeskip;
EXTERN int		frameskip;
EXTERN int		game_index;
EXTERN struct osd_bitmap *bitmap;
EXTERN int		use_scanlines;
EXTERN int		cabview;
EXTERN char		*cabname;
EXTERN float		display_aspect_ratio;
EXTERN int 		sleep_idle;
EXTERN int 		max_autoframeskip;
EXTERN struct sysdep_palette_info display_palette_info;
EXTERN struct sysdep_palette_struct *sysdep_palette;
#ifdef MESS
EXTERN char		*crcdir;
#endif

/* visual is the visual part of the bitmap */
EXTERN int 		visual_width;
EXTERN int		visual_height;
EXTERN struct my_rectangle visual;

/* File descripters for stdout / stderr redirection, without svgalib inter
   fering */
EXTERN FILE *stdout_file;
EXTERN FILE *stderr_file;

/* system dependent functions */
int  sysdep_init(void);
void sysdep_close(void);
int  sysdep_create_display(void);
int  sysdep_display_alloc_palette(int writable_colors);
int  sysdep_display_set_pen(int pen, unsigned char red, unsigned char green, unsigned char blue);
int  sysdep_display_16bpp_capable(void);
void sysdep_update_display(void);
int  sysdep_set_video_mode(void);
void sysdep_set_text_mode(void);

/* input related */
int  osd_input_initpre(void);
int  osd_input_initpost(void);
void osd_input_close(void);
void sysdep_update_keyboard (void);
void sysdep_mouse_poll(void);

/* dirty functions */
int  osd_dirty_init(void);
void osd_dirty_close(void);
void osd_dirty_merge(void);

/* network funtions */
int  osd_net_init(void);
void osd_net_close(void);

/* debug functions */
int  osd_debug_init(void);
void osd_debug_close(void);

/* mode handling functions */
int mode_disabled(int width, int height);
int mode_match(int width, int height);

/* frameskip functions */
int dos_skip_next_frame(int show_fps_counter);
int barath_skip_next_frame(int show_fps_counter);

/* miscelaneous */
int config_init (int argc, char *argv[]);
void config_exit(void);
int frontend_list(char *gamename);
int frontend_ident(char *gamename);
void init_rom_path(void);
#ifndef HAVE_SNPRINTF
int snprintf(char *s, size_t maxlen, const char *fmt, ...);
#endif

/* option structs */
extern struct rc_option video_opts[];
extern struct rc_option display_opts[];
extern struct rc_option mode_opts[];
extern struct rc_option sound_opts[];
extern struct rc_option input_opts[];
extern struct rc_option network_opts[];
extern struct rc_option fileio_opts[];
extern struct rc_option frontend_list_opts[];
extern struct rc_option frontend_ident_opts[];

#undef EXTERN
#endif
